const app = require('electron').app;
const BrowserWindow = require('electron').BrowserWindow;
const path = require('path');
const ipcMain = require('electron').ipcMain;
const closeWindowEventName = 'aboutCloseWindow';

let aboutWindow;

function open() {
  if (aboutWindow) {
    aboutWindow.focus();
    return false;
  }

  aboutWindow = new BrowserWindow({
    'width'           : 300,
    'height'          : process.platform === 'darwin' ? 400 : 440,
    'title'           : 'About ' + app.getName(),
    'resizable'       : false,
    'maximizable'     : false,
    'minimizable'     : false,
    'frame'           : process.platform !== 'darwin',
    'titleBarStyle'   : 'hidden-inset',
    'show'            : false,
    'webPreferences'  : {
      'nodeIntegration'     : true,
      'webSecurity'         : true,
    }
  });

  aboutWindow.loadURL('file://' + path.resolve(__dirname, 'about.html'));
  aboutWindow.on('closed', onAboutWindowClosed);
  aboutWindow.on('ready-to-show', onAboutWindowReadyToShow);

  ipcMain.on(closeWindowEventName, close);

  app.aboutWindow = aboutWindow;
};

function close() {
  if (aboutWindow) {
    aboutWindow.close();
  }
}

function onAboutWindowClosed() {
  aboutWindow = null;
  app.aboutWindow = null;
  ipcMain.removeListener(closeWindowEventName, close);
}

function onAboutWindowReadyToShow() {
  aboutWindow.show();
}

module.exports = {
  'open'      : open,
  'close'     : close
}
